@@ -1,18 +1,24 @@
 module.exports = {
+  root: true,
   env: {
     browser: true,
     commonjs: true,
     node: true
   },
-  extends: ['eslint-config-digitalbazaar'],
+  extends: [
+    'digitalbazaar'
+  ],
   parserOptions: {
-    ecmaVersion: 5
+    ecmaVersion: 5,
+    sourceType: 'script'
   },
   rules: {
     // overrides to support ES5, remove when updated to ES20xx
     'no-unused-vars': 'warn',
     'no-var': 'off',
     'object-shorthand': 'off',
-    'prefer-const': 'off'
+    'prefer-const': 'off',
+    // fix when code is globally reformatted
+    'max-len': 'off'
   }
 };
