@@ -39,7 +39,7 @@ jQuery(function($)
    {
       $('#start').attr('disabled', 'true');
       // meta! use tasks to run the task tests
-      forge.task.start({
+      forge_task.start({
          type: 'test',
          run: function(task) {
             task.next('starting', function(task) {
